<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use SimpleXMLIterator;

class FileLibraryParser implements ItemParser
{
    public const OBJECT_TYPE = 'x-im/file-library';

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill($this->getLinkAttributes($element));
        return [$item];
    }

    private function getLinkAttributes(SimpleXMLIterator $el): array
    {
        $links = (new LinkParser)->parseLinks($el);

        if (!empty($links)) {
            foreach ($links as $link) {
                if ($link instanceof Item) {
                    $attributes = $link->getItemAttributes();
                    if (($attributes['rel'] ?? '') === 'self') {
                        return $attributes;
                    }
                }
            }
        }

        return [];
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
