<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use SimpleXMLIterator;

class ReviewParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-gm/review';

    /**
     * @var ItemParser[]
     */
    private $textParsers;

    public function __construct(ElementParser $parser)
    {
        $this->textParsers = [
            ElementParser::TAG => $parser
        ];
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);

        $item->fill($this->getData($element));

        return [$item];
    }

    protected function getData(SimpleXMLIterator $element): array
    {
        $defaultData = [
            'score' => '',
            'text' => []
        ];
        if (!property_exists($element, 'data')) {
            return $defaultData;
        }

        $data = $element->data->children();

        foreach ($data as $tag => $item) {
            $defaultData[$tag] = $tag === 'text' ? $this->parseText($item->children()) : (string)$item;
        }

        return $defaultData;
    }

    private function parseText(SimpleXMLIterator $textIterator): array
    {
        $items = [[]];

        foreach ($textIterator as $tag => $item) {
            $parser = $this->textParsers[$tag] ?? null;
            $items[] = $parser instanceof ItemParser ? $parser->parse($item) : [new Item($item)];
        }

        return array_merge(...$items);
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
