<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers\Metadata;

use Infomaker\Everyware\NewsML\Parsers\Metadata\PositionParser;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class PositionParserSpec extends ParserSpec
{
    function it_is_initializable()
    {
        $this->shouldHaveType(PositionParser::class);
    }

    public function it_can_parse_an_object()
    {
        $xml = <<<XML
<object id="4pGrYW69CaIf" type="x-im/position">
    <data>
        <geometry>POINT(15.585612639672854 56.164808494834965)</geometry>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'type' => 'x-im/position',
            'id' => '4pGrYW69CaIf',
            'geometry' => 'POINT(15.585612639672854 56.164808494834965)'
        ]);
    }

    public function it_will_add_all_data_child_nodes()
    {
        $xml = <<<XML
<object id="4pGrYW69CaIf" type="x-im/position">
    <data>
        <something>Something</something>
        <unknownTag>UnknownTag</unknownTag>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'something' => 'Something',
            'unknownTag' => 'UnknownTag',
        ]);
    }

    public function it_can_return_type_to_be_parsed()
    {
        $this->typeToParse()
            ->shouldReturn('x-im/position');
    }
}
