<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\RelatedLinksParser;
use PhpSpec\ObjectBehavior;

class RelatedLinksParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(RelatedLinksParser::class);
    }

    public function it_should_parse_multiple_seeAlso_links()
    {
        $xml = '
            <links>
                <link rel="irel:seeAlso" type="x-im/social+twitter" url="twitter.com/jonathanTwitter"/>
                <link rel="irel:seeAlso" type="x-im/social+facebook" url="Facebook.com/jonathan"/>
            </links>
            ';

        $this->validateXML($xml, [
            'twitter' => 'twitter.com/jonathanTwitter',
            'facebook' => 'Facebook.com/jonathan',
        ]);


    }

    public function it_should_only_parse_seeAlso_links()
    {
        $xml = '
            <links>
                <link rel="creator" type="x-im/author" uri="im://author/" url="slap.com"/>
                <link rel="irel:seeAlso" type="x-im/social+twitter" url="twitter.com/the_real_jonathan"/>
                <link rel="irel:seeAso" type="x-im/social+twitter" url="twitter.com/the_misspelled_jonathan"/>
                <link rel="irel:fake" type="x-im/social+twitter" url="twitter.com/the_fake_jonathan"/>
            </links>';

        $this->validateXML($xml, [
                'twitter' => 'twitter.com/the_real_jonathan',
            ]);
    }

    public function it_should_have_a_key_based_on_link_type()
    {
        $xml = '
            <links>
                <link rel="creator" type="x-im/author" uri="im://author/" url="slap.com"/>
                <link rel="irel:seeAlso" type="x-im/social+twitter" url="twitter.com/the_real_jonathan"/>
                <link rel="irel:seeAlso" type="x-im/funplanet" url="funplanet.com/jonathan_91"/>
                <link rel="irel:seeAlso" type="x-im/social+linkedin" url="linkedin.com/jonathan_nilsson"/>
            </links>';

        $this->validateXML($xml, [
                'twitter' => 'twitter.com/the_real_jonathan',
                'funplanet' => 'funplanet.com/jonathan_91',
                'linkedin' => 'linkedin.com/jonathan_nilsson',
            ]);
    }

    public function it_return_empty_array_if_empty_url()
    {
        $xml = '
            <links>
                <link rel="irel:seeAlso" type="x-im/social+twitter" url="" />
            </links>';

        $this->validateXML($xml, []);
    }

    public function it_return_empty_array_if_missing_url()
    {
        $xml = '
            <links>
                <link rel="irel:seeAlso" type="x-im/social+twitter" />
            </links>';

        $this->validateXML($xml, []);
    }

    protected function validateXML($xml, array $matchValues): void
    {
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parseLinks($el)->shouldBeKeysValues($matchValues);
    }
}
