<?php declare(strict_types=1);

namespace Spec\Matchers;

use PhpSpec\Exception\Example\FailureException;
use PhpSpec\Matcher\BasicMatcher;

/**
 * Class ContainItemType
 * @package Spec\Matchers
 */
class ContainItemType extends BasicMatcher
{
    private $names = [
        'containItemType',
        'haveItemType',
        'containItemsOfTypes',
        'haveItemsOfTypes',
    ];

    protected function matches($subject, array $arguments): bool
    {
        $resultTypes = array_column((array)$subject, 'type');
        $expectedTypes = (array)$arguments[0];

        return count(array_intersect($resultTypes, $expectedTypes)) === count($expectedTypes);
    }

    protected function getFailureException(string $name, $subject, array $arguments): FailureException
    {
        return new FailureException(
            implode(PHP_EOL, [
                'expected',
                json_encode($arguments[0] ?? 'empty'),
                'but got ',
                json_encode($subject)
            ])
        );
    }

    protected function getNegativeFailureException(string $name, $subject, array $arguments): FailureException
    {
        return $this->getFailureException($name, $subject, $arguments);
    }

    public function supports(string $name, $subject, array $arguments): bool
    {
        return in_array($name, $this->names, true) && ! empty($arguments);
    }
}
