<?php declare(strict_types=1);

namespace Spec\Matchers;

use Infomaker\Everyware\NewsML\Item;
use PhpSpec\Exception\Example\FailureException;
use PhpSpec\Matcher\BasicMatcher;

/**
 * Class ValidItem
 * @package Spec\Matchers
 */
class ValidItem extends BaseItemValidation
{
    private $names = [
        'beValidItem',
        'returnValidItem'
    ];

    /**
     * @param       $subject
     * @param array $arguments
     *
     * @return bool
     * @throws FailureException
     */
    protected function matches($subject, array $arguments): bool
    {
        $items = (array)$subject;

        $item = $items[0] ?? null;

        $expectedResult = ! empty($arguments) ? $arguments[0] : [];
        $result = $item instanceof Item ? $item->toArray() : [];

        if (empty($expectedResult) && ! empty($result)) {
            throw new FailureException(implode(PHP_EOL, [
                    'Expected empty result',
                    'but got',
                    json_encode($item->toArray(), JSON_PRETTY_PRINT)
                ])
            );
        }

        if ( ! empty($expectedResult) && empty($result)) {
            throw new FailureException(implode(PHP_EOL, [
                    'Did not return any parsed items',
                    'expected',
                    json_encode($expectedResult, JSON_PRETTY_PRINT)
                ])
            );
        }

        if ( ! $item instanceof Item) {
            throw new FailureException(
                sprintf('Failed to parse the object into a "%s".', Item::class)
            );
        }

        $this->matchProperties($expectedResult, $result);

        return true;
    }

    protected function supportedNames(): array
    {
        return $this->names;
    }
}
